@@ -14,12 +14,12 @@
 #' path <- paste0(tempdir(), "/tidy_finance_r.sqlite")
 #' create_wrds_dummy_database(path)
 create_wrds_dummy_database <- function(
-  path, url = paste0(
+  path,
+  url = paste0(
     "https://github.com/tidy-finance/website/tree/main/blog/",
     "tidy-finance-dummy-data/data/tidy_finance.sqlite"
   )
 ) {
-
   if (missing(path)) {
     cli::cli_abort(c(
       "Please provide a file path for the SQLite database.",
@@ -28,7 +28,9 @@ create_wrds_dummy_database <- function(
   }
 
   if (file.exists(path)) {
-    response <- readline(prompt = "The database file already exists at this path. Do you want to replace it? (Y/n): ")
+    response <- readline(
+      prompt = "The database file already exists at this path. Do you want to replace it? (Y/n): "
+    )
     if (tolower(response) != "y") {
       cli::cli_inform("Operation aborted by the user.")
       return(invisible(NULL))
@@ -36,11 +38,12 @@ create_wrds_dummy_database <- function(
   }
 
   handle_download_error(
-    function() suppressWarnings(utils::download.file(
-      url = url,
-      destfile = path,
-      quiet = TRUE
-    ))
+    function()
+      suppressWarnings(utils::download.file(
+        url = url,
+        destfile = path,
+        quiet = TRUE
+      ))
   )
 
   if (file.exists(path)) {
