@@ -11,9 +11,9 @@
 #'
 #' @export
 disconnection_connection <- function(con) {
-
   rlang::check_installed(
-    "DBI", reason = "to download types wrds_*."
+    "DBI",
+    reason = "to download types wrds_*."
   )
 
   DBI::dbDisconnect(con)
