@@ -1,4 +1,3 @@
-
 data <- tibble::tibble(
   permno = rep(1:2, each = 10),
   date = rep(seq.Date(as.Date('2023-01-01'), by = "month", length.out = 10), 2),
@@ -7,15 +6,24 @@ data <- tibble::tibble(
 )
 
 test_that("add_lag_columns adds lagged columns", {
-  result <- add_lag_columns(data, cols = c("bm", "size"), lag = months(3), by = "permno")
+  result <- add_lag_columns(
+    data,
+    cols = c("bm", "size"),
+    lag = months(3),
+    by = "permno"
+  )
   expect_true("bm_lag" %in% colnames(result))
   expect_true("size_lag" %in% colnames(result))
-
 })
 
 test_that("add_lag_columns returns error for negative lag or max_lag", {
   expect_error(add_lag_columns(data, cols = c("bm", "size"), lag = -1))
-  expect_error(add_lag_columns(data, cols = c("bm", "size"), lag = months(3), max_lag = months(1)))
+  expect_error(add_lag_columns(
+    data,
+    cols = c("bm", "size"),
+    lag = months(3),
+    max_lag = months(1)
+  ))
 })
 
 test_that("add_lag_columns works without grouping", {
@@ -25,8 +33,12 @@ test_that("add_lag_columns works without grouping", {
 })
 
 test_that("add_lag_columns preserves original column values", {
-  result <- add_lag_columns(data, cols = c("bm", "size"), lag = months(3), by = "permno")
+  result <- add_lag_columns(
+    data,
+    cols = c("bm", "size"),
+    lag = months(3),
+    by = "permno"
+  )
   expect_equal(result$bm, data$bm)
   expect_equal(result$size, data$size)
 })
-
