@@ -1,4 +1,3 @@
-
 test_that("download_data_fred returns full data set when no date range is provided", {
   skip_if_offline()
   skip_on_cran()
@@ -15,14 +14,22 @@ test_that("download_data_fred handles invalid series ID", {
   skip_if_offline()
   skip_on_cran()
   expect_warning(
-    download_data_fred("INVALID_SERIES", start_date = "2020-12-31", end_date = "2021-01-01"),
+    download_data_fred(
+      "INVALID_SERIES",
+      start_date = "2020-12-31",
+      end_date = "2021-01-01"
+    ),
     regexp = "Failed to retrieve data for series INVALID_SERIES with status code 404."
   )
 })
 
 test_that("download_data_fred handles start_date after end_date", {
   expect_error(
-    download_data_fred("CPIAUCNS", start_date = "2021-12-31", end_date = "2020-01-01"),
+    download_data_fred(
+      "CPIAUCNS",
+      start_date = "2021-12-31",
+      end_date = "2020-01-01"
+    ),
     regexp = "`start_date` cannot be after `end_date`"
   )
 })
