@@ -16,7 +16,9 @@ test_that("download_data_macro_predictors gracefully handles broken url", {
 test_that("download_data_macro_predictors handles start_date after end_date", {
   expect_error(
     download_data_macro_predictors(
-      "macro_predictors_monthly", start_date = "2021-12-31", end_date = "2020-01-01"
+      "macro_predictors_monthly",
+      start_date = "2021-12-31",
+      end_date = "2020-01-01"
     ),
     regexp = "`start_date` cannot be after `end_date`"
   )
